@@ -7,7 +7,7 @@ use utf8;
 use Test::BDD::Cucumber::Definitions qw(Given When Then);
 use Test::BDD::Cucumber::Definitions::File qw(:util);
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 ## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
 ## no critic [RegularExpressions::RequireExtendedFormatting]
@@ -20,6 +20,16 @@ sub import {
         file_path_set($1);
     };
 
+    #       file read text "(.*)"
+    When qr/file read text "(.*)"/, sub {
+        file_read_text($1);
+    };
+
+    #       file read binary
+    When qr/file read binary/, sub {
+        file_read_binary();
+    };
+
     #       file exists
     Then qr/file exists/, sub {
         file_exists();
